package com.simuwang.manage.service.impl;

import com.simuwang.base.common.support.MybatisPage;
import com.simuwang.base.common.util.DateUtils;
import com.simuwang.base.common.util.StringUtil;
import com.simuwang.base.mapper.*;
import com.simuwang.base.pojo.dos.*;
import com.simuwang.base.pojo.dto.query.ParseDetailPageQuery;
import com.simuwang.base.pojo.vo.*;
import com.simuwang.manage.service.FundInformationService;
import com.simuwang.manage.service.ParseEmailDetailService;
import com.smppw.utils.DateUtil;
import org.checkerframework.checker.units.qual.A;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * FileName: ParseEmailDetailServiceImpl
 * Author:   chenjianhua
 * Date:     2024/9/12 23:08
 * Description: ${DESCRIPTION}
 */
@Service
public class ParseEmailDetailServiceImpl implements ParseEmailDetailService {

    @Autowired
    private EmailFundNavMapper emailFundNavMapper;

    @Autowired
    private EmailFundAssetMapper emailFundAssetMapper;

    @Autowired
    private FundInformationService fundInformationService;

    @Override
    public MybatisPage<EmailFundNavVO> searchNavDetail(ParseDetailPageQuery parseDetailPageQuery) {
        if(StringUtil.isNotEmpty(parseDetailPageQuery.getUpdateEndDate())){
            parseDetailPageQuery.setUpdateEndDate(DateUtil.getAroundDate(DateUtils.parse(parseDetailPageQuery.getUpdateEndDate(),DateUtils.YYYY_MM_DD),1));
        }
        List<EmailFundNavDO> dataList = emailFundNavMapper.searchNavDetail(parseDetailPageQuery);
        List<String> fundIdList = dataList.stream().filter(e -> StringUtil.isNotEmpty(e.getFundId())).map(e -> e.getFundId()).collect(Collectors.toList());
        if(!fundIdList.isEmpty()){
            Map<String,String> fundIdNameMap = fundInformationService.getFundIdNameByFundIdList(fundIdList);
            for (EmailFundNavDO emailFundNavDO : dataList) {
                if(StringUtil.isNotEmpty(emailFundNavDO.getFundId())){
                    emailFundNavDO.setTargetFundId(emailFundNavDO.getFundId());
                    emailFundNavDO.setTargetFundName(fundIdNameMap.get(emailFundNavDO.getFundId()));
                }
            }
        }
        List<EmailFundNavVO> voList = dataList.stream().map(EmailFundNavDO::toVo).collect(Collectors.toList());
        long total = emailFundNavMapper.countNavDetail(parseDetailPageQuery);
        return MybatisPage.of(total,voList);
    }

    @Override
    public MybatisPage<EmailFundAssetVO> searchAssetDetail(ParseDetailPageQuery parseDetailPageQuery) {
        if(StringUtil.isNotEmpty(parseDetailPageQuery.getUpdateEndDate())){
            parseDetailPageQuery.setUpdateEndDate(DateUtil.getAroundDate(DateUtils.parse(parseDetailPageQuery.getUpdateEndDate(),DateUtils.YYYY_MM_DD),1));
        }
        List<EmailFundAssetDO> dataList = emailFundAssetMapper.searchAssetDetail(parseDetailPageQuery);
        List<String> fundIdList = dataList.stream().filter(e -> StringUtil.isNotEmpty(e.getFundId())).map(e -> e.getFundId()).collect(Collectors.toList());
        if(!fundIdList.isEmpty()){
            Map<String,String> fundIdNameMap = fundInformationService.getFundIdNameByFundIdList(fundIdList);
            for (EmailFundAssetDO emailFundAssetDO : dataList) {
                if(StringUtil.isNotEmpty(emailFundAssetDO.getFundId())){
                    emailFundAssetDO.setTargetFundId(emailFundAssetDO.getFundId());
                    emailFundAssetDO.setTargetFundName(fundIdNameMap.get(emailFundAssetDO.getFundId()));
                }
            }
        }
        List<EmailFundAssetVO> voList = dataList.stream().map(EmailFundAssetDO::toVo).collect(Collectors.toList());
        long total = emailFundAssetMapper.countAssetDetail(parseDetailPageQuery);
        return MybatisPage.of(total,voList);
    }
}
